@@ -18,7 +18,7 @@ const char* FILE_NAME = "Sys/Poll/PollfdArray";
 
 int32_t SPVM__Sys__Poll__PollfdArray__new(SPVM_ENV* env, SPVM_VALUE* stack) {
   
-  int32_t e = 0;
+  int32_t error_id = 0;
   
   int32_t length = stack[0].ival;
   
@@ -29,11 +29,11 @@ int32_t SPVM__Sys__Poll__PollfdArray__new(SPVM_ENV* env, SPVM_VALUE* stack) {
   struct pollfd* fds = env->new_memory_stack(env, stack, sizeof(struct pollfd) * length);
   
   int32_t fields_length = 1;
-  void* obj_self = env->new_pointer_object_by_name(env, stack, "Sys::Poll::PollfdArray", fds, &e, __func__, FILE_NAME, __LINE__);
-  if (e) { return e; }
+  void* obj_self = env->new_pointer_object_by_name(env, stack, "Sys::Poll::PollfdArray", fds, &error_id, __func__, FILE_NAME, __LINE__);
+  if (error_id) { return error_id; }
   
-  env->set_field_int_by_name(env, stack, obj_self, "length", length, &e, __func__, FILE_NAME, __LINE__);
-  if (e) { return e; }
+  env->set_field_int_by_name(env, stack, obj_self, "length", length, &error_id, __func__, FILE_NAME, __LINE__);
+  if (error_id) { return error_id; }
   
   stack[0].oval = obj_self;
   
@@ -56,14 +56,14 @@ int32_t SPVM__Sys__Poll__PollfdArray__DESTROY(SPVM_ENV* env, SPVM_VALUE* stack)
 
 int32_t SPVM__Sys__Poll__PollfdArray__fd(SPVM_ENV* env, SPVM_VALUE* stack) {
   
-  int32_t e = 0;
+  int32_t error_id = 0;
   
   void* obj_self = stack[0].oval;
   
   int32_t index = stack[1].ival;
   
-  int32_t length = env->get_field_int_by_name(env, stack, obj_self, "length", &e, __func__, FILE_NAME, __LINE__);
-  if (e) { return e; }
+  int32_t length = env->get_field_int_by_name(env, stack, obj_self, "length", &error_id, __func__, FILE_NAME, __LINE__);
+  if (error_id) { return error_id; }
   
   if (!(index >= 0)) {
     return env->die(env, stack, "The index must be greater than or equal to 0", __func__, FILE_NAME, __LINE__);
@@ -84,14 +84,14 @@ int32_t SPVM__Sys__Poll__PollfdArray__fd(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__Poll__PollfdArray__set_fd(SPVM_ENV* env, SPVM_VALUE* stack) {
   
-  int32_t e = 0;
+  int32_t error_id = 0;
   
   void* obj_self = stack[0].oval;
 
   int32_t index = stack[1].ival;
   
-  int32_t length = env->get_field_int_by_name(env, stack, obj_self, "length", &e, __func__, FILE_NAME, __LINE__);
-  if (e) { return e; }
+  int32_t length = env->get_field_int_by_name(env, stack, obj_self, "length", &error_id, __func__, FILE_NAME, __LINE__);
+  if (error_id) { return error_id; }
   
   if (!(index >= 0)) {
     return env->die(env, stack, "The index must be greater than or equal to 0", __func__, FILE_NAME, __LINE__);
@@ -112,7 +112,7 @@ int32_t SPVM__Sys__Poll__PollfdArray__set_fd(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__Poll__PollfdArray__events(SPVM_ENV* env, SPVM_VALUE* stack) {
   
-  int32_t e = 0;
+  int32_t error_id = 0;
   
   void* obj_self = stack[0].oval;
   
@@ -121,8 +121,8 @@ int32_t SPVM__Sys__Poll__PollfdArray__events(SPVM_ENV* env, SPVM_VALUE* stack) {
     return env->die(env, stack, "The index must be greater than or equal to 0", __func__, FILE_NAME, __LINE__);
   }
   
-  int32_t length = env->get_field_int_by_name(env, stack, obj_self, "length", &e, __func__, FILE_NAME, __LINE__);
-  if (e) { return e; }
+  int32_t length = env->get_field_int_by_name(env, stack, obj_self, "length", &error_id, __func__, FILE_NAME, __LINE__);
+  if (error_id) { return error_id; }
   
   if (!(index < length)) {
     return env->die(env, stack, "The index must be less than the length of the file descripters", __func__, FILE_NAME, __LINE__);
@@ -139,7 +139,7 @@ int32_t SPVM__Sys__Poll__PollfdArray__events(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__Poll__PollfdArray__set_events(SPVM_ENV* env, SPVM_VALUE* stack) {
   
-  int32_t e = 0;
+  int32_t error_id = 0;
   
   void* obj_self = stack[0].oval;
 
@@ -148,8 +148,8 @@ int32_t SPVM__Sys__Poll__PollfdArray__set_events(SPVM_ENV* env, SPVM_VALUE* stac
     return env->die(env, stack, "The index must be greater than or equal to 0", __func__, FILE_NAME, __LINE__);
   }
   
-  int32_t length = env->get_field_int_by_name(env, stack, obj_self, "length", &e, __func__, FILE_NAME, __LINE__);
-  if (e) { return e; }
+  int32_t length = env->get_field_int_by_name(env, stack, obj_self, "length", &error_id, __func__, FILE_NAME, __LINE__);
+  if (error_id) { return error_id; }
   
   if (!(index < length)) {
     return env->die(env, stack, "The index must be less than the length of the file descripters", __func__, FILE_NAME, __LINE__);
@@ -166,7 +166,7 @@ int32_t SPVM__Sys__Poll__PollfdArray__set_events(SPVM_ENV* env, SPVM_VALUE* stac
 
 int32_t SPVM__Sys__Poll__PollfdArray__revents(SPVM_ENV* env, SPVM_VALUE* stack) {
   
-  int32_t e = 0;
+  int32_t error_id = 0;
   
   void* obj_self = stack[0].oval;
   
@@ -174,8 +174,8 @@ int32_t SPVM__Sys__Poll__PollfdArray__revents(SPVM_ENV* env, SPVM_VALUE* stack)
   if (!(index >= 0)) {
     return env->die(env, stack, "The index must be greater than or equal to 0", __func__, FILE_NAME, __LINE__);
   }
-  int32_t length = env->get_field_int_by_name(env, stack, obj_self, "length", &e, __func__, FILE_NAME, __LINE__);
-  if (e) { return e; }
+  int32_t length = env->get_field_int_by_name(env, stack, obj_self, "length", &error_id, __func__, FILE_NAME, __LINE__);
+  if (error_id) { return error_id; }
   
   if (!(index < length)) {
     return env->die(env, stack, "The index must be less than the length of the file descripters", __func__, FILE_NAME, __LINE__);
@@ -192,7 +192,7 @@ int32_t SPVM__Sys__Poll__PollfdArray__revents(SPVM_ENV* env, SPVM_VALUE* stack)
 
 int32_t SPVM__Sys__Poll__PollfdArray__set_revents(SPVM_ENV* env, SPVM_VALUE* stack) {
   
-  int32_t e = 0;
+  int32_t error_id = 0;
   
   void* obj_self = stack[0].oval;
 
@@ -201,8 +201,8 @@ int32_t SPVM__Sys__Poll__PollfdArray__set_revents(SPVM_ENV* env, SPVM_VALUE* sta
     return env->die(env, stack, "The index must be greater than or equal to 0", __func__, FILE_NAME, __LINE__);
   }
   
-  int32_t length = env->get_field_int_by_name(env, stack, obj_self, "length", &e, __func__, FILE_NAME, __LINE__);
-  if (e) { return e; }
+  int32_t length = env->get_field_int_by_name(env, stack, obj_self, "length", &error_id, __func__, FILE_NAME, __LINE__);
+  if (error_id) { return error_id; }
   
   if (!(index < length)) {
     return env->die(env, stack, "The index must be less than the length of the file descripters", __func__, FILE_NAME, __LINE__);
