@@ -193,7 +193,7 @@ int32_t SPVM__Sys__Process__pipe(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_pipefds = stack[0].oval;
   
   if (!obj_pipefds) {
-    return env->die(env, stack, "The $pipefds must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$pipefds must be defined", __func__, FILE_NAME, __LINE__);
   }
   
   int32_t pipefds_length = env->length(env, stack, obj_pipefds);
@@ -301,7 +301,7 @@ int32_t SPVM__Sys__Process__execv(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_path = stack[0].oval;
   
   if (!obj_path) {
-    return env->die(env, stack, "The $path must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$path must be defined", __func__, FILE_NAME, __LINE__);
   }
   const char* path = env->get_chars(env, stack, obj_path);
   
@@ -342,7 +342,7 @@ int32_t SPVM__Sys__Process__WIFEXITED(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = WIFEXITED(stack[0].ival);
   return 0;
 #else
-  env->die(env, stack, "WIFEXITED is not defined in this system", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "WIFEXITED is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -354,7 +354,7 @@ int32_t SPVM__Sys__Process__WEXITSTATUS(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = WEXITSTATUS(stack[0].ival);
   return 0;
 #else
-  env->die(env, stack, "WEXITSTATUS is not defined in this system", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "WEXITSTATUS is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -366,7 +366,7 @@ int32_t SPVM__Sys__Process__WIFSIGNALED(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = WIFSIGNALED(stack[0].ival);
   return 0;
 #else
-  env->die(env, stack, "WIFSIGNALED is not defined in this system", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "WIFSIGNALED is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -378,7 +378,7 @@ int32_t SPVM__Sys__Process__WTERMSIG(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = WTERMSIG(stack[0].ival);
   return 0;
 #else
-  env->die(env, stack, "WTERMSIG is not defined in this system", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "WTERMSIG is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -390,7 +390,7 @@ int32_t SPVM__Sys__Process__WCOREDUMP(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = WCOREDUMP(stack[0].ival);
   return 0;
 #else
-  env->die(env, stack, "WCOREDUMP is not defined in this system", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "WCOREDUMP is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -402,7 +402,7 @@ int32_t SPVM__Sys__Process__WIFSTOPPED(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = WIFSTOPPED(stack[0].ival);
   return 0;
 #else
-  env->die(env, stack, "WIFSTOPPED is not defined in this system", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "WIFSTOPPED is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -414,7 +414,7 @@ int32_t SPVM__Sys__Process__WSTOPSIG(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = WSTOPSIG(stack[0].ival);
   return 0;
 #else
-  env->die(env, stack, "WSTOPSIG is not defined in this system", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "WSTOPSIG is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -426,7 +426,7 @@ int32_t SPVM__Sys__Process__WIFCONTINUED(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = WIFCONTINUED(stack[0].ival);
   return 0;
 #else
-  env->die(env, stack, "WIFCONTINUED is not defined in this system", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "WIFCONTINUED is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
