@@ -1,3 +1,6 @@
+// Copyright (c) 2023 Yuki Kimoto
+// MIT License
+
 #include "spvm_native.h"
 
 // The maximum number of sockets that a Windows Sockets application can use is not affected by the manifest constant FD_SETSIZE
@@ -21,12 +24,12 @@ int32_t SPVM__Sys__Select__Fd_set__new(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)env;
   (void)stack;
 
-  int32_t e;
+  int32_t error_id = 0;
 
   fd_set* type_fd_set = env->new_memory_stack(env, stack, sizeof(fd_set));
   
-  void* obj_fd_set = env->new_pointer_object_by_name(env, stack, "Sys::Select::Fd_set", type_fd_set, &e, __func__, FILE_NAME, __LINE__);
-  if (e) { return e; }
+  void* obj_fd_set = env->new_pointer_object_by_name(env, stack, "Sys::Select::Fd_set", type_fd_set, &error_id, __func__, FILE_NAME, __LINE__);
+  if (error_id) { return error_id; }
   
   stack[0].oval = obj_fd_set;
   
@@ -59,7 +62,7 @@ int32_t SPVM__Sys__Select__Fd_set__set(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_fd_set_arg = stack[1].oval;
   if (!obj_fd_set_arg) {
-    return env->die(env, stack, "The $set must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$set must be defined", __func__, FILE_NAME, __LINE__);
   }
   fd_set* type_fd_set_arg = env->get_pointer(env, stack, obj_fd_set_arg);
   
