@@ -12,12 +12,12 @@ int32_t SPVM__Sys__Socket__Addrinfo__new(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)env;
   (void)stack;
   
-  int32_t e = 0;
+  int32_t error_id = 0;
   
   struct addrinfo* addrinfo = env->new_memory_stack(env, stack, sizeof(struct addrinfo));
 
-  void* obj_addrinfo = env->new_pointer_object_by_name(env, stack, "Sys::Socket::Addrinfo", addrinfo, &e, __func__, FILE_NAME, __LINE__);
-  if (e) { return e; }
+  void* obj_addrinfo = env->new_pointer_object_by_name(env, stack, "Sys::Socket::Addrinfo", addrinfo, &error_id, __func__, FILE_NAME, __LINE__);
+  if (error_id) { return error_id; }
   
   stack[0].oval = obj_addrinfo;
   
